// Helper for displaying status messages.
const addMessage = (message, backgroundColor = "#f84242") => {
  const messageDiv = document.querySelector("#messages");
  messageDiv.style.display = "block";
  messageDiv.innerHTML = message + "<br>";
  messageDiv.style.backgroundColor = backgroundColor;
};
const backendClientSecrectURL =
  "https://api.crystalplus.store/orders/payment_intent60";

document.addEventListener("DOMContentLoaded", async () => {
  const publishableKey =
    "pk_test_51OaS2cB9am2eSQTJfw4DY1UbfoJ9WMrORfh6cZY4MKaqB8nyArbEQjpqTEKxu2Ov7BEROxXQFaBN6rAm78CQ1Z5S00lUl9RAPc";

  const stripe = Stripe(publishableKey, {
    apiVersion: "2020-08-27",
  });

  const elements = stripe.elements();
  const cardNumberElement = elements.create("cardNumber");
  const cardEpiryElement = elements.create("cardExpiry");
  const cardCvcElement = elements.create("cardCvc");
  cardNumberElement.mount("#card-number");
  cardEpiryElement.mount("#card-expiry");
  cardCvcElement.mount("#card-cvc");

  // When the form is submitted...
  const form = document.getElementById("payment-form");

  let submitted = false;
  form.addEventListener("submit", async (e) => {
    e.preventDefault();

    // Disable double submission of the form
    if (submitted) {
      return;
    }
    submitted = true;
    form.querySelector("button").disabled = true;
    // change sumbit button innerHTML
    form.querySelector("#pay").innerHTML =
      '<div class="spinner-border" role="status"><span class="sr-only">Loading...</span></div>';

    // Make a call to the server to create a new
    // payment intent and store its client_secret.
    const { error: backendError, clientSecret } = await fetch(
      backendClientSecrectURL,
      {
        method: "POST",
        headers: {
          "Content-Type": "application/json",
        },
        // body: JSON.stringify({
        //   currency: "usd",
        //   paymentMethodType: "card",
        // }),
      }
    ).then((r) => r.json());

    if (backendError) {
      addMessage(backendError.message, "#f84242");

      // reenable the form.
      submitted = false;
      form.querySelector("button").disabled = false;
      form.querySelector("#pay").innerHTML = "Pay €60";
      return;
    }

    // addMessage(`Client secret returned.`);

    const nameInput = document.querySelector("#name");
    const emailInput = document.querySelector("#email");
    const whatsappInput = document.querySelector("#whatsapp");

    // Confirm the card payment given the clientSecret
    // from the payment intent that was just created on
    // the server.
    const { error: stripeError, paymentIntent } =
      await stripe.confirmCardPayment(clientSecret, {
        payment_method: {
          card: cardNumberElement,
          billing_details: {
            name: nameInput.value,
            email: emailInput.value,
            phone: whatsappInput.value,
          },
        },
      });

    if (stripeError) {
      addMessage(stripeError.message, "#f84242");

      // reenable the form.
      submitted = false;
      form.querySelector("button").disabled = false;
      form.querySelector("#pay").innerHTML = "Pay €60";
      //   save in the DB that payment has failed
      return;
    } else if ((paymentIntent.status = "succeeded")) {
      form.querySelector("#pay").innerHTML = "Pay €60";
      addMessage("Payment Succeeded", "#74E291");
      // Save to DB that the client has placed an order
      // API call
      window.location.href = "https://crystalplus.store/thankyou";
    }
  });
});
